# Go API client for monobank

API для отримання інформації про виписки та стан особистого рахунку та рахунків ФОП. Для надання доступу потрібно пройти авторизацію у особистому кабінеті https://api.monobank.ua/ та отримати токен для персонального використання.

Якщо у вас є запитання щодо роботи API, запрошуємо до ком'юніті у [Telegram-групі](https://t.me/joinchat/FiAEWhDf-QzTqM4wzEtffw).
API недоступне для клієнтів до 16 років, дані за дитячими рахунками доступні з батьківського акаунту.
Якщо у вас є сервіс і ви хочете централізовано приєднатися до API для надання послуг клієнтам, потрібно підключитися до [API для провайдерів послуг](/docs/corporate.html), що має більше можливостей. Якщо дані клієнтів не будуть надходити на ваші сервери або ви робите сервіс для своєї родини, використання корпоративного API необов'язкове. Розробка бібліотек або програм, які будуть використовувати клієнти особисто (дані клієнта не будуть проходити черeз вузли розробника), також не потребують використання корпоративного API.

Це надасть змогу клієнтам monobank авторизуватись у вашому сервісі (наприклад, у фінансовому менеджері) для надання інформації про стан рахунку або виписки.

У разі виявлення експлуатації цього API в якості корпоративного, банк залишає за собою право накласти санкції на компанію.

## Overview
This API client was generated by the [OpenAPI Generator](https://monobank-generator.tech) project.  By using the [OpenAPI-spec](https://www.monobanks.org/) from a remote server, you can easily generate an API client.

- API version: v2303
- Package version: 1.0.0
- Generator version: 7.4.0
- Build package: org.monobanktools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```sh
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```go
import monobank "gitea.stuzer.link/stuzer05/go-monobank"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```go
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `monobank.ContextServerIndex` of type `int`.

```go
ctx := context.WithValue(context.Background(), monobank.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `monobank.ContextServerVariables` of type `map[string]string`.

```go
ctx := context.WithValue(context.Background(), monobank.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `monobank.ContextOperationServerIndices` and `monobank.ContextOperationServerVariables` context maps.

```go
ctx := context.WithValue(context.Background(), monobank.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), monobank.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *https://api.monobank.ua*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**BankCurrencyGet**](docs/DefaultApi.md#bankcurrencyget) | **Get** /bank/currency | Отримання курсів валют
*DefaultApi* | [**PersonalClientInfoGet**](docs/DefaultApi.md#personalclientinfoget) | **Get** /personal/client-info | Інформація про клієнта
*DefaultApi* | [**PersonalStatementAccountFromToGet**](docs/DefaultApi.md#personalstatementaccountfromtoget) | **Get** /personal/statement/{account}/{from}/{to} | Виписка
*DefaultApi* | [**PersonalWebhookPost**](docs/DefaultApi.md#personalwebhookpost) | **Post** /personal/webhook | Встановлення WebHook


## Documentation For Models

 - [CurrencyInfoInner](docs/CurrencyInfoInner.md)
 - [Error](docs/Error.md)
 - [SetWebHook](docs/SetWebHook.md)
 - [StatementItemsInner](docs/StatementItemsInner.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserInfoAccountsInner](docs/UserInfoAccountsInner.md)
 - [UserInfoJarsInner](docs/UserInfoJarsInner.md)


## Documentation For Authorization

Endpoints do not require authorization.


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author



